@@ -1,6 +1,6 @@
 context("Latent Order Likeihood")
 
-library(lolog)
+#library(lolog)
 library(testthat)
 library(ergm)
 
